//=========================================================
// src/Interrupts.c: generated by Hardware Configurator
//
// This file will be regenerated when saving a document.
// leave the sections inside the "$[...]" comment tags alone
// or they will be overwritten!
//=========================================================

// USER INCLUDES
#include <SI_EFM8UB2_Register_Enums.h>
#include "Project_DefsVarsFuncs.h"

unsigned char SPI_State = IDLE;

unsigned int RawTempData;
unsigned char TempData[TEMP_DATA_LEN];
bit TEMP_DATA_READY = FALSE;

bit PID_WAIT = TRUE;

//-----------------------------------------------------------------------------
// SPI0_ISR
//-----------------------------------------------------------------------------
//
// SPI0 ISR Content goes here. Remember to clear flag bits:
// SPI0CN0::MODF (Mode Fault Flag)
// SPI0CN0::RXOVRN (Receive Overrun Flag)
// SPI0CN0::SPIF (SPI# Interrupt Flag)
// SPI0CN0::WCOL (Write Collision Flag)
//
//-----------------------------------------------------------------------------
SI_INTERRUPT (SPI0_ISR, SPI0_IRQn)
{
	//SPI registers are on all SFR pages, so need need to modify SFRPAGE

	SPI0CN0_SPIF = 0;	//clear interrupt flag

	switch(SPI_State)
	{
		//SPI communications with thermocouple IC======================================
		case FIRST_TC_BYTE_SENT:
		RawTempData = SPI0DAT;
		SPI0DAT = 0x00;	//write a second dummy byte so that the MAX31855 will continue transmitting
		SPI_State = SECOND_TC_BYTE_SENT;
		break;

		case SECOND_TC_BYTE_SENT:
		TC_NSS = HIGH;	//disable slave select

		RawTempData = (RawTempData << 8) | SPI0DAT;

		/* The following instructions convert the raw
		 * binary temperature data into a format that
		 * both Scilab and the EFM8 can easily convert
		 * into a floating point number.*/
		TempData[0] = LOWBYTE(RawTempData >> 12);
		TempData[1] = LOWBYTE(RawTempData >> 4);
		switch((RawTempData & (BIT3|BIT2)) >> 2)
		{
			case 0: TempData[2] = 0;
			break;

			case 1: TempData[2] = 25;
			break;

			case 2: TempData[2] = 50;
			break;

			case 3: TempData[2] = 75;
			break;
		}
		TEMP_DATA_READY = TRUE;
		SPI_State = IDLE;
		break;

		//SPI communications with DAC===========================================
		case FIRST_DAC_BYTE_SENT:
		SPI0DAT = UpdateDAC_SecondByte;
		SPI_State = SECOND_DAC_BYTE_SENT;
		break;

		case SECOND_DAC_BYTE_SENT:
		DAC_NSS = HIGH;	//disable slave select
		SPI_State = IDLE;
		break;
	}
}
//-----------------------------------------------------------------------------
// PCA0_ISR
//-----------------------------------------------------------------------------
//
// PCA0 ISR Content goes here. Remember to clear flag bits:
// PCA0CN0::CCF0 (PCA Module 0 Capture/Compare Flag)
// PCA0CN0::CCF1 (PCA Module 1 Capture/Compare Flag)
// PCA0CN0::CCF2 (PCA Module 2 Capture/Compare Flag)
// PCA0CN0::CCF3 (PCA Module 3 Capture/Compare Flag)
// PCA0CN0::CCF4 (PCA Module 4 Capture/Compare Flag)
// PCA0CN0::CF (PCA Counter/Timer Overflow Flag)
//
//-----------------------------------------------------------------------------
SI_INTERRUPT (PCA0_ISR, PCA0_IRQn)
{
	//PCA registers are on all SFR pages, so no need to modify SFRPAGE

	PCA0CN0_CF = 0;	//clear interrupt flag

	/*The overflow interrupt fires when the PCA counter/timer
	 * overflows from 0xFFFF to 0x0000, so we create the delay
	 * as follows:*/
	PCA0 = 0x0000 - PID_INTERVAL;	//PID_INTERVAL is the delay in milliseconds

	PID_WAIT = FALSE;
}

